==> dart_blocks-0.0.10.tar.gz: lib/softcorp_authorize/softcorp_authorize.dart <==
import 'package:dart_softcorp_cloud/cloud_project.pbgrpc.dart';
import 'package:jwt_decoder/jwt_decoder.dart';

abstract class Authorize {
  Future<String> getAccessToken();
}

class SoftcorpAuthorize implements Authorize {
  // _grpcProjectClient is an object to communicate with the server
  late final ProjectServiceClient _grpcProjectClient;

  // _apiKey used to authorize requests
  String _apiKey = "";

  // _accessToken is used to connect clients to the api
  String _accessToken = "";

  SoftcorpAuthorize(
      {required ProjectServiceClient projectClient, required String apiKey}) {
    _grpcProjectClient = projectClient;
    _apiKey = apiKey;
  }

  @override
  Future<String> getAccessToken() async {
    // check if we have valid existing tokens
    print("access here -1");
    if (_accessToken != "") {
      // validate tokens
      if (!JwtDecoder.isExpired(_accessToken)) {
        return _accessToken;
      }
    }
    print("access here -2");
    print(_apiKey);
    if (!JwtDecoder.isExpired(_apiKey)) {
      throw Exception("api key is expired or otherwise malformed");
    }
    try {
      print("access here 1");
      ProjectRequest req = ProjectRequest();
      print("access here 2");
      req.privateKey = _apiKey;
      print("access here 3");
      ProjectResponse resp = await _grpcProjectClient.generateAccessToken(req);
      print("access here 4");
      _accessToken = resp.accessToken;
      print("access here 5");
      return _accessToken;
    } catch (e) {
      print("could not get access token");
      rethrow;
    }
  }
}

==> dart_blocks-0.0.11.tar.gz: lib/softcorp_authorize/softcorp_authorize.dart <==
import 'package:dart_softcorp_cloud/cloud_project.pbgrpc.dart';
import 'package:jwt_decoder/jwt_decoder.dart';

abstract class Authorize {
  Future<String> getAccessToken();
}

class SoftcorpAuthorize implements Authorize {
  // _grpcProjectClient is an object to communicate with the server
  late final ProjectServiceClient _grpcProjectClient;

  // _apiKey used to authorize requests
  String _apiKey = "";

  // _accessToken is used to connect clients to the api
  String _accessToken = "";

  SoftcorpAuthorize(
      {required ProjectServiceClient projectClient, required String apiKey}) {
    _grpcProjectClient = projectClient;
    _apiKey = apiKey;
  }

  @override
  Future<String> getAccessToken() async {
    // check if we have valid existing tokens
    print("access here -1");
    if (_accessToken != "") {
      // validate tokens
      if (!JwtDecoder.isExpired(_accessToken)) {
        return _accessToken;
      }
    }
    print("access here -2");
    print(_apiKey);
    //if (!JwtDecoder.isExpired(_apiKey)) {
    //  throw Exception("api key is expired or otherwise malformed");
    //}
    try {
      print("access here 1");
      ProjectRequest req = ProjectRequest();
      print("access here 2");
      req.privateKey = _apiKey;
      print("access here 3");
      ProjectResponse resp = await _grpcProjectClient.generateAccessToken(req);
      print("access here 4");
      _accessToken = resp.accessToken;
      print("access here 5");
      return _accessToken;
    } catch (e) {
      print("could not get access token");
      rethrow;
    }
  }
}
